@@ -8,7 +8,7 @@
  ***************************************************************************/
 
  static char *const _id =
-"$Id: lpc.c,v 1.31 2002/05/06 16:03:44 papowell Exp $";
+"$Id: lpc.c,v 1.36 2002/08/06 19:14:14 papowell Exp $";
 
 
 /***************************************************************************
@@ -62,6 +62,7 @@
  */
 
 #include "lp.h"
+#include "defs.h"
 #include "initialize.h"
 #include "getprinter.h"
 #include "sendreq.h"
@@ -293,6 +294,7 @@ void doaction( struct line_list *args )
 		Merge_line_list(&l,&Config_line_list, 0, 0, 0);
 		Escape_colons( &l );
 		s = Join_line_list_with_sep(&l,"\n :");
+		Expand_percent( &s );
 		if( s ){
 			if( Write_fd_str( 1, ".config\n :" ) < 0 ) cleanup(0);
 			if( Write_fd_str( 1, s ) < 0 ) cleanup(0);
@@ -426,7 +428,24 @@ void Get_parms(int argc, char *argv[] )
 			usage();
 		}
 	}
-	if( Verbose ) FPRINTF( STDERR, "%s\n", Version );
+	if( Verbose ) {
+		FPRINTF( STDOUT, "%s\n", Version );
+		if( Verbose > 1 ){
+			char *s, *t;
+			if( (s = getenv("LANG")) ){
+				FPRINTF( STDOUT, _("LANG environment variable '%s'\n"), s );
+				t = _("");
+				if( t && *t ){
+					FPRINTF( STDOUT, _("gettext translation information '%s'\n"), t );
+				} else {
+					FPRINTF( STDOUT, "%s", _("No translation available\n"));
+				}
+			} else {
+				FPRINTF( STDOUT, "LANG environment variable not set\n" );
+			}
+			Printlist( Copyright, 2 );
+		}
+	}
 }
 
  char *msg[] ={
