@@ -4,7 +4,7 @@
  * Copyright 1988-2002, Patrick Powell, San Diego, CA
  *     papowell@lprng.com
  * See LICENSE for conditions of use.
- * $Id: krb5_auth.h,v 1.31 2002/05/06 16:03:45 papowell Exp $
+ * $Id: krb5_auth.h,v 1.36 2002/08/06 19:14:15 papowell Exp $
  ***************************************************************************/
 
 
@@ -20,13 +20,16 @@ int client_krb5_auth( char *keytabfile, char *service, char *host,
 	int sock, char *err, int errlen, char *file );
 int remote_principal_krb5( char *service, char *host, char *err, int errlen );
 char *krb4_err_str( int err );
-int Send_krb4_auth( struct job *job, int *sock, char **real_host,
+int Send_krb4_auth( struct job *job, int *sock,
 	int connect_timeout, char *errmsg, int errlen,
 	struct security *security, struct line_list *info );
 int Receive_k4auth( int *sock, char *input );
-int Krb5_receive( int *sock, char *user, char *jobsize, int from_server,
-	char *authtype, struct line_list *info,
-	char *error, int errlen, struct line_list *header_info, char *tempfile );
+int Krb5_receive( int *sock,
+	char *user, char *jobsize, int from_server, char *authtype,
+	struct line_list *info,
+	char *errmsg, int errlen,
+	struct line_list *header_info,
+	struct security *security, char *tempfile );
 int Krb5_send( int *sock, int transfer_timeout, char *tempfile,
 	char *error, int errlen,
 	struct security *security, struct line_list *info );
