@@ -4,7 +4,7 @@
  * Copyright 1988-2002, Patrick Powell, San Diego, CA
  *     papowell@lprng.com
  * See LICENSE for conditions of use.
- * $Id: lpd_secure.h,v 1.31 2002/05/06 16:03:46 papowell Exp $
+ * $Id: lpd_secure.h,v 1.36 2002/08/06 19:14:16 papowell Exp $
  ***************************************************************************/
 
 
@@ -14,12 +14,9 @@
 
 /* PROTOTYPES */
 int Receive_secure( int *sock, char *input );
-int Do_secure_work( int use_line_order, char *jobsize, int from_server,
+int Do_secure_work( char *jobsize, int from_server,
 	char *tempfile, struct line_list *header_info );
 struct security *Fix_receive_auth( char *name, struct line_list *info );
-int Pgp_receive( int *sock, char *user, char *jobsize, int from_server,
-	char *authtype, struct line_list *info,
-	char *error, int errlen, struct line_list *header_info, char *tempfile );
 int Check_secure_perms( struct line_list *options, int from_server,
 	char *error, int errlen );
 
